@@ -1297,6 +1297,7 @@ public:
     {
         std::string s;
         Formatter f(s);
+        f.setMode(Formatter::Mode::ECMAScript);
         f.format("%g", value);
         return s;
     }
@@ -3080,6 +3081,8 @@ public:
         CompletionType  result;
         Register<Value> value;
 
+        process();
+
         SourceElement::List::Iterator iter = list.begin();
         while (SourceElement* element = iter.next())
         {
@@ -3099,8 +3102,14 @@ public:
 class FormalParameterList
 {
     mutable Identifier::List    list;
+    int length;
 
 public:
+    FormalParameterList() :
+        length(0)
+    {
+    }
+
     virtual ~FormalParameterList()
     {
         while (!list.isEmpty())
@@ -3112,6 +3121,7 @@ public:
 
     void add(Identifier* parameter)
     {
+        ++length;
         list.addLast(parameter);
     }
 
@@ -3138,6 +3148,11 @@ public:
             variableObject->put(parameter->toString(), (*arguments)[arg++]);
         }
     }
+
+    int getLength() const
+    {
+        return length;
+    }
 };
 
 class FunctionDeclaration : public SourceElement
@@ -3237,30 +3252,24 @@ public:
 
     Value* evaluate()
     {
+        Register<ObjectValue> function = new ObjectValue();
+        function->setParameterList(formalParameterList);
         if (!identifier)
         {
-            Register<ObjectValue> function = new ObjectValue();
             function->setPrototype(getGlobal()->get("Function")->getPrototype());
-            function->setParameterList(formalParameterList);
-            function->setCode(functionBody);
             function->setScope(getScopeChain());
-            Register<ObjectValue> prototype = new ObjectValue;
-            function->put("prototype", prototype);
-            return function;
         }
         else
         {
             Register<ObjectValue> object = new ObjectValue();
             object->setNext(getScopeChain());
-            Register<ObjectValue> function = new ObjectValue();
-            function->setParameterList(formalParameterList);
-            function->setCode(functionBody);
-            function->setScope(object);
-            Register<ObjectValue> prototype = new ObjectValue;
-            function->put("prototype", prototype);
             object->put(identifier->toString(), function); // with { DontDelete, ReadOnly }
-            return function;
+            function->setScope(object);
         }
+        function->setCode(functionBody);
+        Register<ObjectValue> prototype = new ObjectValue;
+        function->put("prototype", prototype);
+        return function;
     };
 };
 
