@@ -155,7 +155,7 @@ public:
         return false;
     }
 
-    virtual Value* toPrimitive(int hint = NumberType)
+    virtual Value* toPrimitive(int hint = UndefinedType)
     {
         return this;
     }
@@ -677,6 +677,8 @@ public:
         return value ? "true" : "false";
     }
 
+    ObjectValue* toObject();
+
     void clear()
     {
     }
@@ -791,6 +793,8 @@ public:
         return (value == 0 || value == NAN) ? false : true;
     }
 
+    ObjectValue* toObject();
+
     double toNumber()
     {
         return value;
@@ -800,6 +804,7 @@ public:
     {
         std::string s;
         Formatter f(s);
+        f.setMode(Formatter::Mode::ECMAScript);
         f.format("%g", value);
         return s;
     }
@@ -933,13 +938,18 @@ public:
         return true;
     }
 
-    Value* toPrimitive(int hint = Value::NumberType);
+    Value* toPrimitive(int hint);
 
     bool toBoolean()
     {
         return true;
     }
 
+    double toNumber()
+    {
+        return toPrimitive(Value::NumberType)->toNumber();
+    };
+
     ObjectValue* toObject()
     {
         return this;
@@ -1053,10 +1063,7 @@ public:
         return parameterList;
     }
 
-    void setParameterList(FormalParameterList* list)
-    {
-        parameterList = list;
-    }
+    void setParameterList(FormalParameterList* list);
 
     void setCode(Code* body)
     {
@@ -1485,9 +1492,12 @@ public:
 extern ObjectValue* getScopeChain();
 extern Value* getThis();
 
-extern ObjectValue* constructStringObject();
 extern ObjectValue* constructArrayObject();
+extern ObjectValue* constructBooleanObject();
+extern ObjectValue* constructDateObject();
 extern ObjectValue* constructMathObject();
 extern ObjectValue* constructRegExpObject();
+extern ObjectValue* constructStringObject();
+extern ObjectValue* constructNumberObject();
 
 #endif  // NINTENDO_ESJS_VALUE_H_INCLUDED
