@@ -1,10 +1,10 @@
-var stdout = System.getOut();
-
 function print(stream)
 {
-    while ((c = stream.read(255)) != '')
+    var buf;
+
+    while ((buf = stream.read(255)) != '')
     {
-        stdout.write(c, c.length);
+        stdout.write(buf, buf.length);
     }
 }
 
@@ -12,11 +12,11 @@ for (var i = 1; i < params.length; ++i)
 {
     try
     {
-        var file = IFile(root.lookup(params[i]));
+        var file = IFile(cwd.lookup(params[i]));
         var stream = file.getStream();
         print(stream);
     }
-    finally
+    catch (e)
     {
     }
 }
