@@ -1,6 +1,3 @@
-var stdout = System.getOut();
-var root = System.getRoot();
-
 if (params.length < 2)
 {
     params[1] = "";
@@ -10,25 +7,22 @@ for (var i = 1; i < params.length; ++i)
 {
     try
     {
-        var iter = root.list(params[i]);
+        var iter = cwd.list(params[i]);
         while (iter.hasNext())
         {
             unknown = iter.next();
-            file = IFile(unknown);
-            name = file.getName(256);
+            binding = IBinding(unknown);
+            name = binding.getName(256);
             if (name != "." && name != "..")
             {
                 stdout.write(name + '\n', name.length + 1);
             }
-            file.release();
+            binding.release();
             unknown.release();
         }
         iter.release();
     }
-    finally
+    catch (e)
     {
     }
 }
-
-stdout.release();
-root.release();
