@@ -290,8 +290,10 @@ public:
             }
         }
 
+#ifdef VERBOSE
         report("param: '%s'\n", p.c_str());
         report("body: '%s'\n", body.c_str());
+#endif
 
         setSource(p);
         FormalParameterList* formalParameterList = parseFormalParameterList();
@@ -302,7 +304,10 @@ public:
 
         setSource(body);
         yyparse();
+
+#ifdef VERBOSE
         program->print();
+#endif
 
         Register<ObjectValue> function = new ObjectValue();
         function->setMortal();
@@ -559,9 +564,10 @@ public:
             s = x->toString();
             setSource(s.c_str());
             yyparse();
-            // program->print();
 
-            program->process();
+#ifdef VERBOSE
+            program->print();
+#endif
 
             try
             {
@@ -590,6 +596,7 @@ public:
             else
             {
                 ASSERT(result.isThrow());
+                value = result.getValue();
                 Value::sweep(true);
                 throw result.getValue();
             }
@@ -741,15 +748,26 @@ void constructGlobalObject()
     ObjectValue* array = constructArrayObject();
     global->put("Array", array);
 
+    // Register Boolean object
+    ObjectValue* boolean = constructBooleanObject();
+    global->put("Boolean", boolean);
+
     // Register RegExp object
     ObjectValue* regexp = constructRegExpObject();
     global->put("RegExp", regexp);
 
+    // Register Date object
+    ObjectValue* date = constructDateObject();
+    global->put("Date", date);
+
     // Register Interface object
     global->put("Interface", constructInterfaceObject());
 
     // Register System object
     global->put("System", constructSystemObject(0));
+
+    // Register Number object
+    global->put("Number", constructNumberObject());
 }
 
 //
@@ -844,7 +862,7 @@ int main(int argc, char* argv[])
 
     constructGlobalObject();
     ExecutionContext* context = new ExecutionContext(getGlobal(), getGlobal());
-    Value::setThresh(1);
+    Value::setThresh(1000);    // Set this thresh to one for testing GC
 
     report("alloc count: %lld\n", Value::getAllocCount());
 
@@ -861,10 +879,9 @@ int main(int argc, char* argv[])
 #endif
         report("yyparse() ok.\n");
 
+#ifdef VERBOSE
         mainProgram->print();
-
-        mainProgram->process();
-
+#endif
         result = mainProgram->evaluate();
     }
     catch (Value* value)
@@ -975,3 +992,17 @@ char* skipSpace(const char* str)
     }
     return (char*) str;
 }
+
+int report(const char* spec, ...)
+{
+    va_list list;
+
+    va_start(list, spec);
+    IStream* output(System()->getOut());
+    Formatter formatter(output);
+    formatter.setMode(Formatter::Mode::ECMAScript);
+    int count = formatter.format(spec, list);
+    output->release();
+    va_end(list);
+    return count;
+}
