@@ -478,11 +478,14 @@ public:
                 else if (type.isInterfacePointer())
                 {
                     InterfacePointerValue* unknown = dynamic_cast<InterfacePointerValue*>(value);
-                    if (!unknown)
+                    if (unknown)
                     {
-                        throw getErrorInstance("TypeError");
+                        argp->ptr = unknown->getObject();
+                    }
+                    else
+                    {
+                        argp->ptr = 0;
                     }
-                    argp->ptr = unknown->getObject();
                     argp->cls = Param::PTR;
                 }
                 else if (type.isString() || type.isPointer())   // XXX
@@ -491,7 +494,7 @@ public:
                     argp->cls = Param::PTR;
                 }
             }
-            else
+            else if (param.isOutput())
             {
                 output = i;
                 if (param.isInterfacePointer())
@@ -811,16 +814,3 @@ ObjectValue* constructSystemObject(void* system)
     object->setPrototype(getGlobal()->get("ICurrentProcess")->get("prototype"));
     return object;
 }
-
-int report(const char* spec, ...)
-{
-    va_list list;
-
-    va_start(list, spec);
-    IStream* output(System()->getOut());
-    Formatter formatter(output);
-    int count = formatter.format(spec, list);
-    output->release();
-    va_end(list);
-    return count;
-}
